@@ -1,9 +1,12 @@
-from pyg_base import dt, dt_bump
+from pyg_base import dt, dt_bump, calendar, cfg_read
 from pyg_mongo._db_cell import db_cell, _updated
 
 __all__ = ['periodic_cell']
 _period = 'period'
 
+_day_start = cfg_read().get('day_start', 0)
+_day_end = cfg_read().get('day_end', 235959)
+
 class periodic_cell(db_cell):
     """
     periodic_cell inherits from db_cell its ability to save itself in MongoDb using its db members
@@ -25,6 +28,9 @@ class periodic_cell(db_cell):
     
     >>> c.updated = dt(-3)
     >>> assert c.run()
+    
+    self = c    
+    
             
     """
     def __init__(self, function = None, output = None, db = None, period = '1b', updated = None, **kwargs):
@@ -33,8 +39,20 @@ class periodic_cell(db_cell):
         super(periodic_cell, self).__init__(function, output = output, db = db, **kwargs)
             
     def run(self):
+        end_date = self.get('end_date')
         time = dt()
-        if self[_updated] is None or dt_bump(self[_updated], self[_period]) < time:
-            return True
-        return super(periodic_cell, self).run() 
+        updated = self.get(_updated)
+        # if self[_updated] is None or dt_bump(self[_updated], self[_period]) < time:
+        if end_date is not None and time > dt(end_date, 1) and updated is not None and dt_bump(updated, self[_period]) >= end_date: ## we expired and last ran near expiry
+            return super(periodic_cell, self).run() 
+        else:
+            cal = calendar(self.get('calendar'))
+            day_start = self.get('day_start', _day_start)
+            day_end = self.get('day_end', _day_end)                            
+            if self[_updated] is None or cal.trade_date(time, 'f', day_start, day_end) > cal.trade_date(self[_updated], 'f', day_start, day_end):
+                return True
+            else:
+                return super(periodic_cell, self).run() 
 
+
+    
